==> mobile_pos-1.0.0.tar.gz: lib/src/views/card_payment/share_receipt_email.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';

import '../../network/api_requests.dart';

class ShareReceiptEmail extends StatefulWidget {
  final String? rrn;
  const ShareReceiptEmail({super.key, this.rrn});

  @override
  State<ShareReceiptEmail> createState() => _ShareReceiptEmailState();
}

class _ShareReceiptEmailState extends State<ShareReceiptEmail> {
  final emailController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
      bottomNavigationBar: Padding(
        padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            RavenPayButton(
              enabled: emailController.text.contains("@"),
              buttonText: "Proceed",
              onPressed: () async {
                if (!emailController.text.contains("@")) {
                  showSnack(context, "invalid email address");
                  return;
                }
                var result = await ApiRequests.sendEmailReceipt(
                    context, emailController.text, widget.rrn);

                if (result) {
                  // toRavenPayHome(context);
                  Navigator.pop(context);
                }
              },
            ),
            const Gap(24),
            const PoweredByRaven(fontSize: 9),
            const Gap(24),
          ],
        ),
      ),
      body: Padding(
        padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
        child: Column(
          children: [
            const Gap(24),
            const Row(
              children: [
                RavenPayCloseButton(
                  text: "",
                  isArrow: true,
                ),
                Spacer(),
              ],
            ),
            const Gap(24),
            Align(
                alignment: Alignment.centerLeft,
                child: Text("Share to Email", style: headling1)),
            const Gap(12),
            RichText(
                text: TextSpan(
                    text:
                        "Add your customer Email address to share this receipt to them directly.",
                    style: subtitle2.copyWith(fontSize: 14),
                    children: const [])),
            const Gap(40),
            RavenPayTextField(
              counterText: '',
              onChanged: (val) {
                setState(() {});
              },
              hintText: "customer@mail.com",
              inputType: TextInputType.emailAddress,
              controller: emailController,
              labelText: "Email Address",
            ),
          ],
        ),
      ),
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/card_payment/share_receipt_email.dart <==
import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_textfeild.dart';

import '../../network/api_requests.dart';

class ShareReceiptEmail extends StatefulWidget {
  final String? rrn;
  final String? category;
  const ShareReceiptEmail({super.key, this.rrn, this.category});

  @override
  State<ShareReceiptEmail> createState() => _ShareReceiptEmailState();
}

class _ShareReceiptEmailState extends State<ShareReceiptEmail> {
  final emailController = TextEditingController();
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
      bottomNavigationBar: Padding(
        padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            RavenPayButton(
              enabled: emailController.text.contains("@"),
              buttonText: "Proceed",
              onPressed: () async {
                if (!emailController.text.contains("@")) {
                  showSnack(context, "invalid email address");
                  return;
                }
                var result = await ApiRequests.sendEmailReceipt(
                    context, emailController.text, widget.rrn,
                    category: widget.category);

                if (result) {
                  // toRavenPayHome(context);
                  Navigator.pop(context);
                }
              },
            ),
            const Gap(24),
            const PoweredByRaven(fontSize: 9),
            const Gap(24),
          ],
        ),
      ),
      body: Padding(
        padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
        child: Column(
          children: [
            const Gap(24),
            const Row(
              children: [
                RavenPayCloseButton(
                  text: "",
                  isArrow: true,
                ),
                Spacer(),
              ],
            ),
            const Gap(24),
            Align(
                alignment: Alignment.centerLeft,
                child: Text("Share to Email", style: headling1)),
            const Gap(12),
            RichText(
                text: TextSpan(
                    text:
                        "Add your customer Email address to share this receipt to them directly.",
                    style: subtitle2.copyWith(fontSize: 14),
                    children: const [])),
            const Gap(40),
            RavenPayTextField(
              counterText: '',
              onChanged: (val) {
                setState(() {});
              },
              hintText: "customer@mail.com",
              inputType: TextInputType.emailAddress,
              controller: emailController,
              labelText: "Email Address",
            ),
          ],
        ),
      ),
    );
  }
}
